<?php
/*
 * @file: Additional functions for administrative tasks and interfaces.
 */

/*
 * Validation Handler.
 * Makes sure annotation settings are properly validated.
 */
function research_annotator_validate($form, &$form_state) {
  
  if (
    $form_state['values']['research_annotator_settings']['research_annotator_enabled'] !== 0 &&
    $form_state['values']['research_annotator_settings']['research_annotator_block_region'] === '0'
  ) {
    form_set_error('research_annotator_settings][research_annotator_block_region', t('Please select a block region for your annotations.'));
  }
  if (
    $form_state['values']['research_annotator_settings']['research_annotator_enabled'] !== 0 &&
    $form_state['values']['research_annotator_settings']['research_annotator_date_format'] === ''
  ) {
    form_set_error('research_annotator_settings][research_annotator_date_format', t('Please specify a date format for your annotations.'));
  }
  
}

/*
 * Submission Handler.
 * Handles the setting of annotation variables.
 */
function research_annotator_submit($form, &$form_state) {
  
  // Get a field identifier so we can save variables on a per content type basis.
  $s_fieldIdentifier = $form['#instance']['field_name'] . '_' . $form['#instance']['bundle'];
  
  if ($form_state['values']['research_annotator_settings']['research_annotator_enabled'] == 0) {
    variable_del('research_annotator_' . $s_fieldIdentifier . '_enabled');
    variable_del('research_annotator_' . $s_fieldIdentifier . '_date_format');
    variable_del('research_annotator_' . $s_fieldIdentifier . '_block_region');
    variable_del('research_annotator_' . $s_fieldIdentifier . '_block_weight');
  }
  else {
    variable_set(
      'research_annotator_' . $s_fieldIdentifier . '_enabled', 
      $form_state['values']['research_annotator_settings']['research_annotator_enabled']
    );
    
    variable_set(
      'research_annotator_' . $s_fieldIdentifier . '_date_format', 
      $form_state['values']['research_annotator_settings']['research_annotator_date_format']
    );

    variable_set(
      'research_annotator_' . $s_fieldIdentifier . '_block_region', 
      $form_state['values']['research_annotator_settings']['research_annotator_block_region']
    );

    variable_set(
      'research_annotator_' . $s_fieldIdentifier . '_block_weight', 
      (integer) $form_state['values']['research_annotator_settings']['research_annotator_block_weight']
    );

  }
}

/**
 * Submission Handler.
 * Updates annotations when an annotated node gets reverted to a previous version.
 */
function research_annotator_node_reversion_submit($form, &$form_state) {
  
  $i_oldVid = $form_state['build_info']['args'][0]->old_vid;
  $i_newVid = $form_state['build_info']['args'][0]->vid;
  
  $o_entityQuery = new EntityFieldQuery();
  $arr_result = $o_entityQuery
    ->entityCondition('entity_type', 'research_annotation')
    ->propertyCondition('revision_id', (int) $i_oldVid)
    ->execute();
  
  $arr_annotationIds = array(-1);
  
  if (!empty($arr_result)) {
    $arr_result = $arr_result['research_annotation'];
    
    foreach ($arr_result as $o_annotationId) {
      array_push($arr_annotationIds, $o_annotationId->annotation_id);
    }
  }
  
  $arr_annotations = entity_load('research_annotation', $arr_annotationIds);
  
  foreach ($arr_annotations as $o_annotation) {
    $o_annotation->revision_id = $i_newVid;
    entity_save('research_annotation', $o_annotation);
  }
}

/*
 * Helper function.
 * Returns select list options for the block region field.
 */
function research_annotator_get_block_regions() {

  $arr_blockRegions = system_region_list(variable_get('theme_default'), REGIONS_VISIBLE);
  array_unshift($arr_blockRegions, t('- None -'));
  
  return $arr_blockRegions;
}
