/**
 * @file: Front-end functionality of the research annotator module.
 *        This javascript takes care of user interactions and the setting of hidden
 *        form values. Therefore it is crucial that you do not modify this file 
 *        or use javascript that conflicts with this functionality.
 */

(function ($) {
  Drupal.behaviors.researchAnnotator = {
    attach: function (context, settings) {
          
      /*
       * Helper function. 
       * Sets form variables and performs visuals based on the paragraph you want to annotate.
       * @param i_paragraphIndex: The index of the paragraph you want to annotate. Index starts at 1.
       */
      function research_annotator_change_annotated_paragraph(i_paragraphIndex, o_annotatableElements){
        $($(o_annotatableElements).get(i_paragraphIndex - 1)).addClass('annotatable-selected');
        $('input[name="paragraph_index"]').val(i_paragraphIndex);
        $('.annotating-prompt').text(Drupal.t('Annotating paragraph number @paragraph_index', {'@paragraph_index': i_paragraphIndex}));
        $('input[name="paragraph_index"]').val(i_paragraphIndex);
      }
      
      // Prepare annotatable elements to be used in our javascript.
      var s_annotatableElements = 'p, table, ul, ol';
      var o_annotatableElements = $('.annotated-body').find(s_annotatableElements);
      
      $(o_annotatableElements).each(function(i_index, m_value){
        if($(m_value).text() == String.fromCharCode(160)){
          $($(o_annotatableElements).get(i_index)).remove();
        }  
      });

      var o_annotatableElements = $('.annotated-body').find(s_annotatableElements);

      // Create some visuals on page load based on previous form submissions.
      if($('input[name="paragraph_index"]').val() !== ''){
        research_annotator_change_annotated_paragraph($('input[name="paragraph_index"]').val(), o_annotatableElements);
      }
      
      // Interacting with annotatable paragraphs.
      $(o_annotatableElements).hover(
        function(){
          $(this).before('<div class="annotate-this">' + Drupal.t('Click to annotate.') + '<div class="annotate-corner"></div></div>');
        },
        function(){
          $('.annotate-this').remove();
          $('.annotate-corner').remove();
        }
      );
      
      $(o_annotatableElements).click(function(){
        $(o_annotatableElements).removeClass('annotatable-selected');
        $(this).addClass('annotatable-selected');
        research_annotator_change_annotated_paragraph($(o_annotatableElements).index($(this).get(0)) + 1, o_annotatableElements);
        $('html, body').animate({scrollTop: $('form#annotation-creation').offset().top - 200}, 1000);
      });
      
      // Functionality for interacting with existing annotations.
      $('h3[trigger="toggle-annotation-display"]').click(function(){
        var i_index = $(this).attr('id').match(/\d+/g);
        i_index = i_index[0];
        
        if($(this).parent().hasClass('annotation-section-minimized')){
          
          $(this).parent().siblings('.annotation-section-maximized')
          .removeClass('annotation-section-maximized')
          .addClass('annotation-section-minimized');
          
          $(this).parent()
          .removeClass('annotation-section-minimized')
          .addClass('annotation-section-maximized');
          
          $('html, body').animate({scrollTop: $(this).offset().top - 50}, 1000);
          $(o_annotatableElements).removeClass('annotatable-selected');
          research_annotator_change_annotated_paragraph(i_index, o_annotatableElements);
        }
        else{
          
          $(this).parent().removeClass('annotation-section-maximized').addClass('annotation-section-minimized');
          $(o_annotatableElements).removeClass('annotatable-selected');
        }
      });
      
      // Visuals on annotation edit page.
      var i_paragraphIndex = $('#annotation-edit input[name="paragraph_index"]').val();
      $($('.annotation-content-edit').children(s_annotatableElements).get(i_paragraphIndex - 1)).addClass('annotatable-selected');
      $('.annotation-content-edit').children('*').not('.annotatable-selected').remove();
    }
  };
})(jQuery);
